# GetPaymentMethodSnapshotResponseBankTransferType

Specifies the type of direct debit transfer. The value of this field is dependent on the country of the user.  Possible Values:    * `AutomatischIncasso` (NL)  * `LastschriftDE` (Germany)  * `LastschriftAT` (Austria)  * `DemandeDePrelevement` (FR)  * `DirectDebitUK` (UK)  * `Domicil` (Belgium)  * `LastschriftCH` (CH)  * `RID` (Italy)  * `OrdenDeDomiciliacion` (Spain) * `Autogiro` (Sweden) * `Betalingsservice` (Denmark) 

## Enum

* `AUTOMATISCHINCASSO` (value: `'AutomatischIncasso'`)

* `LASTSCHRIFTDE` (value: `'LastschriftDE'`)

* `LASTSCHRIFTAT` (value: `'LastschriftAT'`)

* `DEMANDEDEPRELEVEMENT` (value: `'DemandeDePrelevement'`)

* `DIRECTDEBITUK` (value: `'DirectDebitUK'`)

* `DOMICIL` (value: `'Domicil'`)

* `LASTSCHRIFTCH` (value: `'LastschriftCH'`)

* `RID` (value: `'RID'`)

* `ORDENDEDOMICILIACION` (value: `'OrdenDeDomiciliacion'`)

* `AUTOGIRO` (value: `'Autogiro'`)

* `BETALINGSSERVICE` (value: `'Betalingsservice'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


